==> PyGUI-1.7.tar.gz: PyGUI-1.7/GUI/Cocoa/Menus.py <==
#
#		Python GUI - Menus - PyObjC
#

from AppKit import NSMenu, NSMenuItem, NSOnState, \
    NSCommandKeyMask, NSShiftKeyMask, NSAlternateKeyMask
import Applications, GApplications
from GMenus import Menu as GMenu, MenuItem

class Menu(GMenu):

    def __init__(self, title, items, **kwds):
        GMenu.__init__(self, title, items, **kwds)
        self._ns_menu = NSMenu.alloc().initWithTitle_(title)
        self._ns_menu.setAutoenablesItems_(False)
    
    def _clear_platform_menu(self):
        ns_menu = self._ns_menu
        n = ns_menu.numberOfItems()
        while n:
            n -= 1
            ns_menu.removeItemAtIndex_(n)
    
    def _add_separator_to_platform_menu(self):
        ns_item = NSMenuItem.separatorItem()
        self._ns_menu.addItem_(ns_item)
    
    def _add_item_to_platform_menu(self, item, name, command = None, index = None):
        key = item._key or ""
        if item._shift:
            key = key.upper()
        else:
            key = key.lower()
        #name = item._label.replace("<app>", GApplications.application_name)
        ns_item = NSMenuItem.alloc()
        ns_item.initWithTitle_action_keyEquivalent_(name, 'menuSelection:', key)
        ns_item.setEnabled_(item.enabled)
        if item.checked:
            ns_item.setState_(NSOnState)
        ns_modifiers = NSCommandKeyMask
        if item._option:
            ns_modifiers |= NSAlternateKeyMask
        ns_item.setKeyEquivalentModifierMask_(ns_modifiers)
        ns_item.setRepresentedObject_(command)
        if index is not None:
            ns_tag = index
        else:
            ns_tag = -1
        ns_item.setTag_(ns_tag)
        ns_item.setTarget_(Applications.ns_application)
        self._ns_menu.addItem_(ns_item)


#class PyGUI_NSMenu(NSMenu):
#
#	def title(self):
#		s = NSMenu.title(self)
#		print "PyGUI_NSMenu: title:", s
#		return s.upper()

==> PyGUI-1.7.2-1.tar.gz: PyGUI-1.7.2/GUI/Cocoa/Menus.py <==
#
#		Python GUI - Menus - PyObjC
#

from AppKit import NSMenu, NSMenuItem, NSOnState, \
    NSCommandKeyMask, NSShiftKeyMask, NSAlternateKeyMask
from GMenus import Menu as GMenu, MenuItem

_ns_standard_actions = {
    'undo_cmd': 'undo:',
    'redo_cmd': 'redo:',
    'cut_cmd': 'cut:',
    'copy_cmd': 'copy:',
    'paste_cmd': 'paste:',
    'clear_cmd': 'clear:',
    'select_all_cmd': 'selectAll:',
}

class Menu(GMenu):

    def __init__(self, title, items, **kwds):
        GMenu.__init__(self, title, items, **kwds)
        self._ns_menu = NSMenu.alloc().initWithTitle_(title)
        self._ns_menu.setAutoenablesItems_(False)
    
    def _clear_platform_menu(self):
        ns_menu = self._ns_menu
        n = ns_menu.numberOfItems()
        while n:
            n -= 1
            ns_menu.removeItemAtIndex_(n)
    
    def _add_separator_to_platform_menu(self):
        ns_item = NSMenuItem.separatorItem()
        self._ns_menu.addItem_(ns_item)
    
    def _add_item_to_platform_menu(self, item, name, command = None, index = None):
        key = item._key or ""
        if item._shift:
            key = key.upper()
        else:
            key = key.lower()
        ns_item = NSMenuItem.alloc()
        ns_action = _ns_standard_actions.get(command, 'menuSelection:')
        ns_item.initWithTitle_action_keyEquivalent_(name, ns_action, key)
        ns_item.setEnabled_(item.enabled)
        if item.checked:
            ns_item.setState_(NSOnState)
        ns_modifiers = NSCommandKeyMask
        if item._option:
            ns_modifiers |= NSAlternateKeyMask
        ns_item.setKeyEquivalentModifierMask_(ns_modifiers)
        ns_item.setRepresentedObject_(command)
        if index is not None:
            ns_tag = index
        else:
            ns_tag = -1
        ns_item.setTag_(ns_tag)
        self._ns_menu.addItem_(ns_item)
